import unidecode
import pickle
import os

class Lemmatizer():
    def __init__(self):
        if (os.path.exists('pt_lemmatizer/lemmatizer.pickle')):
            print('loading lemmatizer dict (pt_lemmatizer/lemmatizer.pickle)')
            self.lemmatizer_dict = self.load_lemmatizer_dict()
        else:
            print('generating lemmatizer dict (pt_lemmatizer/lemmatizer.pickle)')
            self.lemmatizer_dict = self.generate_lemmatizer_dict()

    def generate_lemmatizer_dict(self):
        file_name = 'pt_lemmatizer/data/lemmatization-pt.txt'

        with open(file_name, encoding="utf-8") as f:
            lemmatizer_dict = {}
            for l in list(f)[1:]:
                words = l.rstrip().split("\t")
                word = unidecode.unidecode(words[0]).strip().lower()
                infl = unidecode.unidecode(words[1]).strip().lower()
                if (len(set(word)) > 1):
                    if (word not in lemmatizer_dict.keys()):
                        lemmatizer_dict[word] = [infl]
                    else:
                        lemmatizer_dict[word].append(infl)
        inverse_lemmatizer_dict = {}
        for k, v in lemmatizer_dict.items():
            for w in v:
                inverse_lemmatizer_dict[w] = k

        pickle.dump(inverse_lemmatizer_dict, open("pt_lemmatizer/lemmatizer.pickle", "wb"))
        return inverse_lemmatizer_dict

    def load_lemmatizer_dict(self):
        return pickle.load(open("pt_lemmatizer/lemmatizer.pickle", "rb"))

    def get_lemma(self, word):
        return self.lemmatizer_dict.get(word, word)

if __name__ == '__main__':
    l = Lemmatizer()
    w = 'apagou'
    print("word:", w)
    print("lemma:", l.get_lemma(w))


from setuptools import setup, find_packages 
import codecs 
import os

VERSION = '0.1.8' 
DESCRIPTION = 'A NLP package for Portuguese Lemmatization.' 
LONG_DESCRIPTION = '''
This NLP package for Portuguese lemmatization is a powerful and advanced tool that can accurately transform words into their base forms or lemmas, taking into account the specific grammatical rules and variations of the Portuguese language. It is designed to handle various types of text input and supports multiple output formats, making it a versatile tool for applications such as information retrieval, machine translation, sentiment analysis, and text classification. Additionally, the package is customizable and user-friendly, allowing users to specify their own dictionaries and rules for lemmatization and providing features for error correction and word sense disambiguation.
Whether you are a researcher, developer, or linguist working with Portuguese text data, this NLP package can help you save time and improve the accuracy and quality of your analyses. With its advanced algorithms and techniques in NLP, you can trust that this tool will provide high-quality results and make the lemmatization process more efficient.

*_A lemma is a word that stands at the head of a definition in a dictionary._* [Wikipedia](https://simple.wikipedia.org/wiki/Lemma_(linguistics)#:~:text=A%20lemma%20is%20a%20word,you%20find%20in%20the%20dictionary.)
### Example
```
from pt_lemmatizer import Lemmatizer

l = Lemmatizer()
l.get_lemma('apagou')  #all words must be unidecoded and lowercased
>> 'apagar'
l.get_lemma('nasalaram')
>> 'nasalar'

'''

# Setting up 
setup( 
    name="pt_lemmatizer", 
    version=VERSION, 
    author="Naomi Lago", 
    author_email="<info@naomilago.com>", 
    description=DESCRIPTION, 
    long_description_content_type="text/markdown", 
    long_description=LONG_DESCRIPTION, 
    packages=find_packages(), 
    install_requires=['unidecode', 'pickle'], 
    keywords=['python', 'portuguese', 'lemmatizer', 'nlp'], 
    classifiers=[ 
        "Development Status :: 5 - Production/Stable", 
        "Intended Audience :: Developers", 
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ] 
)